pub(crate) struct PrecomputedTxData {
tx_data: TransactionData<PrecomputedAuth>,
txid_parts: TxDigests<Hash>,
all_previous_outputs: Arc<Vec<Output>>,
}Expand description
Precomputed data used for sighash or txid computation.
Fields
tx_data: TransactionData<PrecomputedAuth>txid_parts: TxDigests<Hash>all_previous_outputs: Arc<Vec<Output>>Implementations
Sourceimpl PrecomputedTxData
impl PrecomputedTxData
Sourcepub(crate) fn new(
tx: &Transaction,
nu: NetworkUpgrade,
all_previous_outputs: Arc<Vec<Output>>,
) -> Result<PrecomputedTxData, Error>
pub(crate) fn new( tx: &Transaction, nu: NetworkUpgrade, all_previous_outputs: Arc<Vec<Output>>, ) -> Result<PrecomputedTxData, Error>
Computes the data used for sighash or txid computation.
Inputs
tx: the relevant transaction.nu: the network upgrade to which the transaction belongs.all_previous_outputs: the transparent Output matching each transparent input intx.
Errors
- If
txcan’t be converted to itslibrustzcashequivalent. - If
nudoesn’t contain a consensus branch id convertible to itslibrustzcashequivalent.
Consensus
[NU5 only, pre-NU6] All transactions MUST use the NU5 consensus branch ID
0xF919A198as defined in ZIP-252.
[NU6 only] All transactions MUST use the NU6 consensus branch ID
0xC8E71055as defined in ZIP-253.
Notes
The check that ensures compliance with the two consensus rules stated above takes place in
the Transaction::to_librustzcash method. If the check fails, the tx can’t be converted
to its librustzcash equivalent, which leads to an error. The check relies on the passed
nu parameter, which uniquely represents a consensus branch id and can, therefore, be used
as an equivalent to a consensus branch id. The desired nu is set either by the script or
tx verifier in zebra-consensus.
Sourcepub fn orchard_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
pub fn orchard_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
Returns the Orchard bundle in tx_data.
Sourcepub fn sapling_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
pub fn sapling_bundle(&self) -> Option<Bundle<Authorized, ZatBalance>>
Returns the Sapling bundle in tx_data.